addGlobalFilter static method

void addGlobalFilter(
  1. LeakFilter filter
)

Adds filter to the global filter using logical OR composition.

The resulting filter ignores allocations matched by either the existing filter or the newly provided filter.

Implementation

static void addGlobalFilter(LeakFilter filter) =>
    globalFilter = globalFilter | filter;