enableInDebug static method
void
enableInDebug()
Enables tracking native memory allocations only in debug and profile builds.
Implementation
static void enableInDebug() {
if (!isReleaseMode) enable();
}
Enables tracking native memory allocations only in debug and profile builds.
static void enableInDebug() {
if (!isReleaseMode) enable();
}