globalFilter property
Global filter applied to all allocations unless overridden by a scoped execution zone.
This allows suppressing known or intentionally retained allocations.
Implementation
static var globalFilter = const LeakFilter.ignoreNone();
Global filter applied to all allocations unless overridden by a scoped execution zone.
This allows suppressing known or intentionally retained allocations.
static var globalFilter = const LeakFilter.ignoreNone();