filter property

LeakFilter filter
final

The filter that determined which allocations count as leaks.

This provides context for diagnostics so that consumers can understand why specific allocations were included in the report.

Implementation

final LeakFilter filter;