totalBytes property
int
get
totalBytes
Sum of the sizes of all leaked allocations, in bytes.
Implementation
int get totalBytes => leaks.fold(0, (sum, a) => sum + a.size);
Sum of the sizes of all leaked allocations, in bytes.
int get totalBytes => leaks.fold(0, (sum, a) => sum + a.size);