OrFilter class final

Logical OR combination of multiple filters.

An allocation is ignored if any contained filter ignores it.

Inheritance

Properties

filters List<LeakFilter>
Component filters.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(LeakFilter other) LeakFilter
Returns a filter representing the logical AND of this filter and other.
inherited
ignore(Allocation allocation) bool
Returns true if the given allocation should be ignored.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() LeakFilter
Returns the logical negation of this filter.
inherited
or(LeakFilter other) LeakFilter
Returns a filter representing the logical OR of this filter and other.
inherited
toString() String
Returns a human-readable description of this filter.
override

Operators

operator &(LeakFilter other) LeakFilter
Logical AND operator alias for and.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator |(LeakFilter other) LeakFilter
Logical OR operator alias for or.
inherited