PrintEmitter class final

Emits leaks as a formatted console report.

The output is designed for human readability and includes:

  • summary statistics
  • sorted leaks (largest first)
  • per-allocation metadata
  • colored output when ANSI is supported

If the terminal does not support ANSI escape sequences, all styling is automatically disabled.

Implemented types

Constructors

PrintEmitter()
Creates a console-printing emitter.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emit(List<Allocation> leaks) → void
Generates and prints a leak report to stdout.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited