nativeFree property
Pointer<NativeFinalizerFunction>
get
nativeFree
A pointer to the platform's native free function.
Pass this to a NativeFinalizer to ensure memory is released automatically if the owning Dart object is garbage collected before free is called.
Implementation
Pointer<NativeFinalizerFunction> get nativeFree =>
Platform.isWindows ? coTaskMemFreeAddress : posixFreeAddress;