DiagnosticMallocAllocator class final
A non-zero-initializing TrackingAllocator.
Memory is not zeroed before it is returned. Integrates with the leak tracker to record allocation metadata when leak tracking is enabled.
Platform behavior:
- Windows: uses
CoTaskMemAlloc/CoTaskMemFree - POSIX: uses
malloc/free
Obtain an instance via diagnosticMalloc. Do not instantiate directly.
- Implemented types
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nativeFree
→ Pointer<
NativeFinalizerFunction> -
A pointer to the native free function used by this allocator.
no setteroverride
-
nativeFree
→ Pointer<
NativeFinalizerFunction> -
Available on Allocator, provided by the AllocatorExtensions extension
A pointer to the platform's native free function.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allocate<
T extends NativeType> (int byteCount, {int? alignment}) → Pointer< T> -
Allocates
byteCountbytes of memory on the native heap.override -
call<
T extends SizedNativeType> ([int count = 1]) → Pointer< T> -
Available on Allocator, provided by the AllocatorAlloc extension
AllocatessizeOf<T>() * countbytes of memory using allocate. -
free(
Pointer< NativeType> pointer) → void -
Releases memory allocated on the native heap.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited